﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using InstrumentDrivers; //namespace from rsupv64.cs

namespace rsupv_csharp_simple_example
{
    class Program
    {
        static void Main(string[] args)
        {
            rsupv upv = null;
            try //separate try-catch for specan initialization prevents accessing uninitialized object
            {
                //-----------------------------------------------------------
                //Initialization:
                //-----------------------------------------------------------
                upv = new rsupv("TCPIP::192.168.2.101::INSTR", true, true);
            }
            catch (Exception e)
            {
                Console.WriteLine("Error initializing the specan session:\n{0}", e.Message);
                Console.WriteLine("Press any key to finish.");
                Console.ReadKey();
                return;
            }

            try
            {
                upv.SetMeasurementMode(0);
                upv.ConfigureGeneratorAnalog(1, rsupvConstants.GenOutputUnbal, rsupvConstants.GenImpedance10, rsupvConstants.GenOutputCommGnd, rsupvConstants.GenBwidth22, rsupvConstants.GenVoltRangAuto, 10.0, rsupvConstants.UnitV);

                // Config trigger
                upv.SetMeasurementMode(0);
                // config universal analog generator
                upv.ConfigureGeneratorAnalog(1, rsupvConstants.GenOutputUnbal, rsupvConstants.GenImpedance10, rsupvConstants.GenOutputCommGnd, rsupvConstants.GenBwidth22, rsupvConstants.GenVoltRangAuto, 10.0, rsupvConstants.UnitV);
                // Configure Generator Reference
                upv.ConfigureGeneratorReference(10.0, rsupvConstants.UnitV, 1000.0, rsupvConstants.UnitHz);
                // Configure Generator Function
                upv.SetGeneratorFunction(rsupvConstants.GenFuncSine);
                // Set Generator Sine Low Distortion
                upv.SetGeneratorSineLowDistortion(false);
                // Set Generator DC Offset
                upv.SetGeneratorDCOffset(false);
                // Set Generator Voltage
                upv.SetGeneratorVoltage(1, 1.0, rsupvConstants.UnitV);
                // Set Generator Frequency
                upv.SetGeneratorFrequency(1, 1000.0, rsupvConstants.UnitHz);
                // Set Analyzer Channel Input
                upv.SetAnalyzerChannelInput(1, rsupvConstants.AnalyzerChInputBal);
                // Set Analyzer Ref Impedance
                upv.SetAnalyzerRefImpedance(600.0);
                // Set Analyzer Channel Input Range
                upv.SetAnalyzerChannelInputRange(1, rsupvConstants.AnalyzerChInputRangeAuto);
                // Set Analyzer Channel Input Common
                upv.SetAnalyzerChannelInputCommon(1, rsupvConstants.AnalyzerChInputCommonFloat);
                // Generator Ch1: Internal connection of analyzer channel 1 to generator output 1. The analyzer input impedance is 200 kOhm.
                upv.SetAnalyzerChannelInput(1, rsupvConstants.AnalyzerChInputBal);
                // Set Analyzer Level Meas Time
                upv.SetAnalyzerLevelMeasTime(rsupvConstants.AnalyzerMeasTimeAfas);
                // Configure Analyzer Notch Filter
                upv.ConfigureAnalyzerNotchFilter(rsupvConstants.AnalyzerNotchGainOff, rsupvConstants.AnalyzerNotchFreqFix, 10.0);
                // Set Analyzer Filter
                upv.SetAnalyzerFilter(1, rsupvConstants.AnalyzerPrefilterOff);
                // Set Analyzer Function
                upv.SetAnalyzerFunction(rsupvConstants.AnalyzerFuncRms);
                // Set Unit    
                upv.SetAnalyzerUnit(1, rsupvConstants.AnalyzerMeasurementFunc, rsupvConstants.UnitDbv);
                // Set Aux Speaker
                upv.SetAuxSpeaker(false);
                // Set Aux Monitoring Channel
                upv.SetAuxMonitoringChannel(rsupvConstants.AuxChannelCh1);
                // Set Generator Voltage
                upv.SetGeneratorVoltage(1, 0.707, rsupvConstants.UnitV);
                // Set Generator Modulation Frequency
                upv.SetGeneratorModulationFrequency(1000, rsupvConstants.UnitHz);

                //Initiate the measurement and read the result
                upv.StartMeasurementWaitOPC(15000);

                double value;
                StringBuilder units = new StringBuilder(100);
                upv.ReadMeasurementResult(1, rsupvConstants.MeasurementFunction, out value, units);
                Console.WriteLine("Measurement result: {0} {1}", value, units);
            }
            catch (Exception e)
            {
                Console.WriteLine("Exception occured:\n{0}", e.Message);
                Console.WriteLine("Press any key to finish.");
                Console.ReadKey();
                return;
            }
        }
    }
}
